window.Gleam.initSearch([{"doc":"meadow","title":"meadow","content":"# Meadow\r\n\r\nA server side for glare, the web framework based on SolidJS, adding server signals and more.\r\n\r\n## Installation\r\n\r\nCreate a new gleam project and install glare and meadow.\r\n\r\n```sh\r\ngleam new my-project\r\ncd my-project\r\n\r\n# Install glare and meadow\r\ngleam add glare\r\ngleam add meadow\r\n```\r\n\r\n## Usage\r\n\r\nCreate a new file `src/my-project.gleam` and add the following code:\r\n\r\n```gleam\r\nimport meadow.{start_server}\r\nimport web/index\r\n\r\n@target(erlang)\r\npub fn main() {\r\n  start_server([index.server])\r\n}\r\n```\r\n\r\nCreate a new file `src/web/index.gleam` and add the following code:\r\n\r\n```gleam\r\nimport meadow.{html, server_signal}\r\nimport glare.{signal, text}\r\nimport glare/element.{button, header, p}\r\nimport glare/event.{onclick}\r\nimport glare/property.{class, font_family, size}\r\nimport gleam/io\r\nimport gleam/int\r\n\r\nconst count_signal = meadow.Signal(0, &quot;index-count&quot;)\r\n\r\n@target(javascript)\r\npub fn client() {\r\n  let #(count, set_count) = server_signal(count_signal)\r\n\r\n  html([\r\n    header([\r\n      p([text(&quot;Title&quot;)])\r\n      |&gt; font_family(&quot;Arial&quot;)\r\n      |&gt; size(&quot;1.5rem&quot;)\r\n      |&gt; class(&quot;title&quot;),\r\n    ]),\r\n    p([text(&quot;count: &quot;), signal(count)]),\r\n    button([text(&quot;click me&quot;)])\r\n      |&gt; onclick(fn() {\r\n      io.println(&quot;clicked&quot;)\r\n      set_count(count() + 1)\r\n    }),\r\n  ])\r\n}\r\n\r\n@target(erlang)\r\npub fn server(s) {\r\n  s\r\n  |&gt; server_signal(count_signal, fn(a) {\r\n    io.println(&quot;count: &quot; &lt;&gt; int.to_string(a))\r\n    a + 2\r\n  })\r\n}\r\n```\r\n\r\n## Running the server\r\n\r\n```sh\r\ngleam build -t=js &amp;&amp; gleam run\r\n```\r\n\r\nThis first builds the JavaScript frontend and then runs the Erlang server.\r\n","url":"index.html"},{"doc":"server","title":"Handler","content":"pub type Handler(a) {\n  Signal(name: String, initial_value: a, handler: fn(a) -&gt; a)\n}\n\nSignal(name: String, initial_value: a, handler: fn(a) -&gt; a)\n\n\nSynonyms:\nserver.Handler\nserver Handler","url":"server.html#Handler"},{"doc":"server","title":"server","content":"pub fn server(handlers: List(Handler(a))) -&gt; Nil\n\nSynonyms:\nserver.server\nserver server","url":"server.html#server"},{"doc":"server","title":"server","content":"","url":"server.html"},{"doc":"meadow","title":"Signal","content":"pub type Signal(a) {\n  Signal(value: a, name: String)\n}\n This type is used to have the signal available both on the client and the server.\n Just provide an initial value and a fun name.\n The name should start with the path to the page you are working on.\n The name can only contain alphanumeric characters and dashes.\nSignal(value: a, name: String)\n\n\nSynonyms:\nmeadow.Signal\nmeadow Signal","url":"meadow.html#Signal"},{"doc":"meadow","title":"html","content":"pub fn html(: a) -&gt; Nil\n ### JavaScript:\n Render the Glare code to the body of the page.\n ### Erlang:\n Does nothing, but is provided for ease of use.\n This makes sure you don&#39;t need the `@target(javascript)` annotation.\nSynonyms:\nmeadow.html\nmeadow html","url":"meadow.html#html"},{"doc":"meadow","title":"server_signal","content":"pub fn server_signal(\n  prev: List(Handler(a)),\n  signal: Signal(a),\n  handle: fn(a) -&gt; a,\n) -&gt; List(Handler(a))\n ### Erlang:\n Initialize the signal on the server side.\n This function is called by piping the argument of the `server` method to it.\n It also takes a handler function that should return the new value of the signal.\n \n Call it like this: `s |&gt; server_signal(count_signal, fn(a) { a + 1 })`\n \n ### JavaScript:\n `pub fn server_signal(signal: Signal(a)) -&gt; #(fn() -&gt; a, fn(a) -&gt; Nil)`\n Initialize the signal on the client side.\n Returns a get and set function in that order.\n \n Call it like this: `let #(count, set_count) = server_signal(count_signal)`\nSynonyms:\nmeadow.server_signal\nmeadow server_signal","url":"meadow.html#server_signal"},{"doc":"meadow","title":"start_server","content":"pub fn start_server(\n  routes: List(fn(List(Handler(Int))) -&gt; List(Handler(Int))),\n) -&gt; Nil\n ### Erlang:\n Start the server.\n This should be the only function called from the main function.\n Its argument should be a list of all the `server` functions in your project.\n ### JavaScript:\n Does nothing, but is provided for ease of use.\n This makes sure you don&#39;t need the `@target(erlang)` annotation.\nSynonyms:\nmeadow.start_server\nmeadow start_server","url":"meadow.html#start_server"},{"doc":"meadow","title":"meadow","content":"","url":"meadow.html"}]);